# transaction_analyzer_cu

## Описание

Это простой Python-пакет, который анализирует данные о транзакциях из CSV-файла и генерирует отчет с суммами по категориям (доходы и расходы).


## Установка и использование

```bash
pip install transaction_analyzer_cu